==> cordova-sqlite-react-1.1.7.tgz: package/SqliteClass/Sqlite.ts <==
import { E_SQLitePayloadType } from './../stringSQL/generateCREATE';
import { 
  openDbSqlite, checkTableSqlite, setDataSqlite, updateDataSqlite,
  getDataSqlite, removeDataSqlite, dropTableSqlite } from '../SqliteFunction';
import { getDataT, setDataT, remoteDataT, updateDataT, commonMethodSqliteT } from './../@types/commonType';


interface SqliteConstructor {
  column: {[key: string]: "ID" | "TEXT" | "INTEGER"};
};

export class Sqlite {
  public constructor ({column}:SqliteConstructor){
    
    // this.column = column;
  }


  static openDB = (nameDbSqlite?: string) => openDbSqlite(nameDbSqlite)

  static checkTable:commonMethodSqliteT = (nameTable) => { 
    return new Promise((resolve, reject) => {
      checkTableSqlite(Sqlite.openDB(), nameTable)
      .then(resolve)
      .catch(reject)
    })
  }

  static setData:setDataT = (nameTable, payload, options) => {
    
    return new Promise((resolve, reject) => {
      setDataSqlite(Sqlite.openDB(), nameTable, payload, options)
      .then(resolve)
      .catch(reject)
    });
    
  }

  static updateData:updateDataT = (nameTable, payload, { where, stringWhere, condition }) => {
    return new Promise((resolve, reject) => {
      
      updateDataSqlite(Sqlite.openDB(), nameTable, payload, {where, stringWhere, condition})
      .then(resolve)
      .catch(reject)
    });
  }

  static getData:getDataT = (nameTable, { where, sql }) => {
    return new Promise((resolve, reject) => {
      getDataSqlite(Sqlite.openDB(), nameTable, { where, sql })
      .then(resolve)
      .catch(reject)
    })
  }

  static removeData:remoteDataT = (nameTable, param) => {
    return new Promise((resolve, reject) => {
      removeDataSqlite(Sqlite.openDB(), nameTable, param)
      .then(resolve)
      .catch(reject)
    })
  }

  static dropTable:commonMethodSqliteT = (nameTable) => {
    return new Promise((resolve, reject) => {
      dropTableSqlite(Sqlite.openDB(), nameTable)
      .then(resolve)
      .catch(reject)
    })
  }
}



(window as any).Sqlite = Sqlite



      //   let db = SLStore.openDbSqlite();
      //  //не проверяю таблицу в отдельной транзакции
      //   db.transaction(
      //     (tx) => {
      //       try {
          
      //         tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${SLStore.nameTable.config}'`, [],
      //         async (tx, res) => {
      //             if(res.rows.item(0) && res.rows.item(0).name === SLStore.nameTable.config){ 
      //               console.log("key>>>:", key);
      //               console.log("value>>>:", value);
                    
                  
      //               let res = await SLStore.setDateInTable(key, value);
                    
      //               resolve(res)


      //             }else{

      //               console.dir(`Попали в транзакцию создания таблицы ${SLStore.nameTable.config}`);
      //               let payload = { key, value, type: typeof value };
      //               console.log('payload DarkMode для SLStore.setDataSqlite', payload);
      //               let dataStatus:object = await SLStore.setDataSqlite(payload, SLStore.nameTable.config);
      //               console.log('dataStatus в SLStore.setItem', dataStatus);
      //               resolve(dataStatus);

      //             }                                   
      //           },
      //           (err) => { console.log(`Ошибка транзакции в SLStore.checkTable: ${(err as any).message}.`); reject('Ошибка проверки таблицы') },    
      //         ); 

      //       } catch (error) {
      //         console.log('Ошибка в catch setItem при проверке или создании таблицы', error);
      //       } 
           
      //     },
      //     (err) => { console.log(`Ошибка транзакции в SLStore.setItem: ${err.message}.`); reject('Ошибка одной из транзакций sqlite localStorage') },    
      //     () => { console.log(`Успешная транзакция в SLStore.setItem.`); }  
              
      //   );



        // if(window.sqlitePlugin){

        //   let db = SLStore.openDbSqlite();
        //   console.dir('Выполняется getItem');
        //   db.transaction(
        //     (tx) => {
          
        //       tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${SLStore.nameTable.config}'`, [],
        //         (tx, res) => {  console.dir('Поиск таблицы в getItem');
                  
        //           if(res.rows.item(0) && res.rows.item(0).name === SLStore.nameTable.config){    
          
        //             tx.executeSql(`SELECT * FROM ${SLStore.nameTable.config} WHERE key='${key}'`, [], 
        //               (tx, res) => { 
                        
                        
        //                 console.log('Всё что нашлось, то и вернём в resolve/ getItem', res.rows.item(0));
        //                 resolve({
        //                   ...res.rows.item(0),
        //                   value: (res.rows.item(0).type === 'object' || res.rows.item(0).type === 'boolean')
        //                           ? JSON.parse(res.rows.item(0).value)
        //                           : res.rows.item(0).value,
        //                   status: true
        //                 });                                            
        //               },
        //               (tx, err) => {console.error(err); }  
        //             );
                
        //             return;
        //           }
                
        //           resolve({status: false, msg: 'Таблицы ещё не существует. Нужно, для начала что-то положить.'});                                        
        //         },
        //         (tx, err) => console.error(err)
        //       ); 
        //     },
        //     (error) => { console.log('Ошибка транзакции в SLStore.getItem: '); reject({status: false, error}); }, 
        //     () => { console.log('Успех транзакции SLStore.getItem');  }
        //   );
    
        //   return;
        // }

        // reject(new Error('Не установлен плагин cordova-sqlite-storage'));








  // static getAll = () => {
  //   return new Promise<{status: boolean, value?: any, msg?: string}>((resolve, reject) => {
  //     let nameTable = SLStore.nameTable.config;
  //     getDataSqlite(nameTable, `SELECT * FROM ${nameTable}`)
  //     .then(resolve)
  //     .catch(reject)
  //   })
  // }


  // static setDateInTable = (key, value) => {
  //   return new Promise( (resolve, reject) => {
  //     let db = SLStore.openDbSqlite();

  //     db.transaction(
  //       (tx) => {
  //         tx.executeSql(`SELECT * FROM ${SLStore.nameTable.config} WHERE key='${key}'`, [], 
  //         //Если есть данные и они не совпадают то обновим, если нет их совсем - добавим
  //           (tx, res) => {
             
  //             console.log('res.rows.item(0): ', res.rows.item(0));
             
  //             if(!res.rows.length){
                
                
  //               tx.executeSql(`INSERT INTO ${SLStore.nameTable.config}(key, value, type) VALUES (?,?,?)`, 
  //                 [
  //                   key,
  //                   ((typeof value === 'object') || (typeof value === 'boolean')) ? JSON.stringify(value) : value,
  //                   typeof value
  //                 ],
  //                 () => {resolve({status: true, msg: 'Успешно положили данные в sqlite LocalStorage'})}
  //               );
    
  //             }else if(res.rows.item(0).value !== value){
  //               console.dir('Обновляем данные SLStore');
  //               tx.executeSql(`UPDATE ${SLStore.nameTable.config} SET value = ?, type = ? WHERE key='${key}'`,
  //                 [
  //                   (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value,
  //                   typeof value
  //                 ],
  //                 (tx, res) => { resolve({status: true, id: res.insertId})}
  //               );
    
  //             }else{
    
  //               resolve({status: true, msg: 'Данные не обновил т.к. значение тоже'});
    
  //             }
  //           } 
  //         )
  //       },
  //       (err) => { console.log(`Ошибка транзакции в SLStore.setItem: ${err.message}.`); reject('Ошибка одной из транзакций sqlite localStorage') },
  //       () => { console.log(`Успешная транзакция в SLStore.setItem.`); }
  //     )

  //   })
  // }

==> cordova-sqlite-react-1.1.10.tgz: package/SqliteClass/Sqlite.ts <==
import { E_SQLitePayloadType } from './../stringSQL/generateCREATE';
import { 
  openDbSqlite, checkTableSqlite, setDataSqlite, updateDataSqlite,
  getDataSqlite, removeDataSqlite, dropTableSqlite } from '../SqliteFunction';
import { getDataT, setDataT, remoteDataT, updateDataT, commonMethodSqliteT } from './../@types/commonType';


interface SqliteConstructor {
  column: {[key: string]: "ID" | "TEXT" | "INTEGER"};
};

export class Sqlite {
  public constructor ({column}:SqliteConstructor){
    
    // this.column = column;
  }


  static openDB = (nameDbSqlite?: string) => openDbSqlite(nameDbSqlite)

  static checkTable:commonMethodSqliteT = (nameTable?:string) => { 
    return new Promise((resolve, reject) => {
      checkTableSqlite(Sqlite.openDB(), nameTable)
      .then(resolve)
      .catch(reject)
    })
  }

  static setData:setDataT = (nameTable, payload, options) => {
    
    return new Promise((resolve, reject) => {
      setDataSqlite(Sqlite.openDB(), nameTable, payload, options)
      .then(resolve)
      .catch(reject)
    });
    
  }

  static updateData:updateDataT = (nameTable, payload, { where, stringWhere, condition }) => {
    return new Promise((resolve, reject) => {
      
      updateDataSqlite(Sqlite.openDB(), nameTable, payload, {where, stringWhere, condition})
      .then(resolve)
      .catch(reject)
    });
  }

  static getData:getDataT = (nameTable, {where, whereKey, ignoreWhere, stringWhere, condition}) => {
    return new Promise((resolve, reject) => {
      getDataSqlite(Sqlite.openDB(), nameTable, {where, whereKey, ignoreWhere, stringWhere, condition})
      .then(resolve)
      .catch(reject)
    })
  }

  static removeData:remoteDataT = (nameTable, {where, whereKey, ignoreWhere, stringWhere, condition}) => {
    return new Promise((resolve, reject) => {
      removeDataSqlite(Sqlite.openDB(), nameTable, {where, whereKey, ignoreWhere, stringWhere, condition})
      .then(resolve)
      .catch(reject)
    })
  }

  static dropTable:commonMethodSqliteT = (nameTable) => {
    return new Promise((resolve, reject) => {
      dropTableSqlite(Sqlite.openDB(), nameTable)
      .then(resolve)
      .catch(reject)
    })
  }
}



(window as any).Sqlite = Sqlite



      //   let db = SLStore.openDbSqlite();
      //  //не проверяю таблицу в отдельной транзакции
      //   db.transaction(
      //     (tx) => {
      //       try {
          
      //         tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${SLStore.nameTable.config}'`, [],
      //         async (tx, res) => {
      //             if(res.rows.item(0) && res.rows.item(0).name === SLStore.nameTable.config){ 
      //               console.log("key>>>:", key);
      //               console.log("value>>>:", value);
                    
                  
      //               let res = await SLStore.setDateInTable(key, value);
                    
      //               resolve(res)


      //             }else{

      //               console.dir(`Попали в транзакцию создания таблицы ${SLStore.nameTable.config}`);
      //               let payload = { key, value, type: typeof value };
      //               console.log('payload DarkMode для SLStore.setDataSqlite', payload);
      //               let dataStatus:object = await SLStore.setDataSqlite(payload, SLStore.nameTable.config);
      //               console.log('dataStatus в SLStore.setItem', dataStatus);
      //               resolve(dataStatus);

      //             }                                   
      //           },
      //           (err) => { console.log(`Ошибка транзакции в SLStore.checkTable: ${(err as any).message}.`); reject('Ошибка проверки таблицы') },    
      //         ); 

      //       } catch (error) {
      //         console.log('Ошибка в catch setItem при проверке или создании таблицы', error);
      //       } 
           
      //     },
      //     (err) => { console.log(`Ошибка транзакции в SLStore.setItem: ${err.message}.`); reject('Ошибка одной из транзакций sqlite localStorage') },    
      //     () => { console.log(`Успешная транзакция в SLStore.setItem.`); }  
              
      //   );



        // if(window.sqlitePlugin){

        //   let db = SLStore.openDbSqlite();
        //   console.dir('Выполняется getItem');
        //   db.transaction(
        //     (tx) => {
          
        //       tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${SLStore.nameTable.config}'`, [],
        //         (tx, res) => {  console.dir('Поиск таблицы в getItem');
                  
        //           if(res.rows.item(0) && res.rows.item(0).name === SLStore.nameTable.config){    
          
        //             tx.executeSql(`SELECT * FROM ${SLStore.nameTable.config} WHERE key='${key}'`, [], 
        //               (tx, res) => { 
                        
                        
        //                 console.log('Всё что нашлось, то и вернём в resolve/ getItem', res.rows.item(0));
        //                 resolve({
        //                   ...res.rows.item(0),
        //                   value: (res.rows.item(0).type === 'object' || res.rows.item(0).type === 'boolean')
        //                           ? JSON.parse(res.rows.item(0).value)
        //                           : res.rows.item(0).value,
        //                   status: true
        //                 });                                            
        //               },
        //               (tx, err) => {console.error(err); }  
        //             );
                
        //             return;
        //           }
                
        //           resolve({status: false, msg: 'Таблицы ещё не существует. Нужно, для начала что-то положить.'});                                        
        //         },
        //         (tx, err) => console.error(err)
        //       ); 
        //     },
        //     (error) => { console.log('Ошибка транзакции в SLStore.getItem: '); reject({status: false, error}); }, 
        //     () => { console.log('Успех транзакции SLStore.getItem');  }
        //   );
    
        //   return;
        // }

        // reject(new Error('Не установлен плагин cordova-sqlite-storage'));








  // static getAll = () => {
  //   return new Promise<{status: boolean, value?: any, msg?: string}>((resolve, reject) => {
  //     let nameTable = SLStore.nameTable.config;
  //     getDataSqlite(nameTable, `SELECT * FROM ${nameTable}`)
  //     .then(resolve)
  //     .catch(reject)
  //   })
  // }


  // static setDateInTable = (key, value) => {
  //   return new Promise( (resolve, reject) => {
  //     let db = SLStore.openDbSqlite();

  //     db.transaction(
  //       (tx) => {
  //         tx.executeSql(`SELECT * FROM ${SLStore.nameTable.config} WHERE key='${key}'`, [], 
  //         //Если есть данные и они не совпадают то обновим, если нет их совсем - добавим
  //           (tx, res) => {
             
  //             console.log('res.rows.item(0): ', res.rows.item(0));
             
  //             if(!res.rows.length){
                
                
  //               tx.executeSql(`INSERT INTO ${SLStore.nameTable.config}(key, value, type) VALUES (?,?,?)`, 
  //                 [
  //                   key,
  //                   ((typeof value === 'object') || (typeof value === 'boolean')) ? JSON.stringify(value) : value,
  //                   typeof value
  //                 ],
  //                 () => {resolve({status: true, msg: 'Успешно положили данные в sqlite LocalStorage'})}
  //               );
    
  //             }else if(res.rows.item(0).value !== value){
  //               console.dir('Обновляем данные SLStore');
  //               tx.executeSql(`UPDATE ${SLStore.nameTable.config} SET value = ?, type = ? WHERE key='${key}'`,
  //                 [
  //                   (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value,
  //                   typeof value
  //                 ],
  //                 (tx, res) => { resolve({status: true, id: res.insertId})}
  //               );
    
  //             }else{
    
  //               resolve({status: true, msg: 'Данные не обновил т.к. значение тоже'});
    
  //             }
  //           } 
  //         )
  //       },
  //       (err) => { console.log(`Ошибка транзакции в SLStore.setItem: ${err.message}.`); reject('Ошибка одной из транзакций sqlite localStorage') },
  //       () => { console.log(`Успешная транзакция в SLStore.setItem.`); }
  //     )

  //   })
  // }
